@@ -1,13 +1,12 @@
-use pep440_rs::{Operator, Version, VersionSpecifier, VersionSpecifiers};
-use pep508_rs::{MarkerExpression, MarkerTree, MarkerValueVersion, StringVersion};
-use uv_toolchain::{Interpreter, PythonVersion};
+use pep440_rs::{Version, VersionSpecifiers};
+use uv_python::{Interpreter, PythonVersion};
 
-use crate::RequiresPython;
+use crate::{RequiresPython, RequiresPythonBound};
 
 #[derive(Debug, Clone, Eq, PartialEq)]
 pub struct PythonRequirement {
     /// The installed version of Python.
-    installed: StringVersion,
+    installed: Version,
     /// The target version of Python; that is, the version of Python for which we are resolving
     /// dependencies. This is typically the same as the installed version, but may be different
     /// when specifying an alternate Python version for the resolution.
@@ -21,11 +20,10 @@ impl PythonRequirement {
     /// [`PythonVersion`].
     pub fn from_python_version(interpreter: &Interpreter, python_version: &PythonVersion) -> Self {
         Self {
-            installed: interpreter.python_full_version().clone(),
-            target: Some(PythonTarget::Version(StringVersion {
-                string: python_version.to_string(),
-                version: python_version.python_full_version(),
-            })),
+            installed: interpreter.python_full_version().version.only_release(),
+            target: Some(PythonTarget::Version(
+                python_version.python_full_version().only_release(),
+            )),
         }
     }
 
@@ -36,7 +34,7 @@ impl PythonRequirement {
         requires_python: &RequiresPython,
     ) -> Self {
         Self {
-            installed: interpreter.python_full_version().clone(),
+            installed: interpreter.python_full_version().version.only_release(),
             target: Some(PythonTarget::RequiresPython(requires_python.clone())),
         }
     }
@@ -44,13 +42,26 @@ impl PythonRequirement {
     /// Create a [`PythonRequirement`] to resolve against an [`Interpreter`].
     pub fn from_interpreter(interpreter: &Interpreter) -> Self {
         Self {
-            installed: interpreter.python_full_version().clone(),
+            installed: interpreter.python_full_version().version.only_release(),
             target: None,
         }
     }
 
+    /// Narrow the [`PythonRequirement`] to the given version, if it's stricter (i.e., greater)
+    /// than the current `Requires-Python` minimum.
+    pub fn narrow(&self, target: &RequiresPythonBound) -> Option<Self> {
+        let Some(PythonTarget::RequiresPython(requires_python)) = self.target.as_ref() else {
+            return None;
+        };
+        let requires_python = requires_python.narrow(target)?;
+        Some(Self {
+            installed: self.installed.clone(),
+            target: Some(PythonTarget::RequiresPython(requires_python)),
+        })
+    }
+
     /// Return the installed version of Python.
-    pub fn installed(&self) -> &StringVersion {
+    pub fn installed(&self) -> &Version {
         &self.installed
     }
 
@@ -58,34 +69,6 @@ impl PythonRequirement {
     pub fn target(&self) -> Option<&PythonTarget> {
         self.target.as_ref()
     }
-
-    /// Return a [`MarkerTree`] representing the Python requirement.
-    ///
-    /// See: [`RequiresPython::to_marker_tree`]
-    pub fn to_marker_tree(&self) -> MarkerTree {
-        let version = match &self.target {
-            None => self.installed.version.clone(),
-            Some(PythonTarget::Version(version)) => version.version.clone(),
-            Some(PythonTarget::RequiresPython(requires_python)) => {
-                return requires_python.to_marker_tree()
-            }
-        };
-
-        let version_major_minor_only = Version::new(version.release().iter().take(2));
-        let expr_python_version = MarkerExpression::Version {
-            key: MarkerValueVersion::PythonVersion,
-            specifier: VersionSpecifier::from_version(Operator::Equal, version_major_minor_only)
-                .unwrap(),
-        };
-        let expr_python_full_version = MarkerExpression::Version {
-            key: MarkerValueVersion::PythonFullVersion,
-            specifier: VersionSpecifier::from_version(Operator::Equal, version).unwrap(),
-        };
-        MarkerTree::And(vec![
-            MarkerTree::Expression(expr_python_version),
-            MarkerTree::Expression(expr_python_full_version),
-        ])
-    }
 }
 
 #[derive(Debug, Clone, Eq, PartialEq)]
@@ -95,7 +78,7 @@ pub enum PythonTarget {
     ///
     /// The use of a separate enum variant allows us to use a verbatim representation when reporting
     /// back to the user.
-    Version(StringVersion),
+    Version(Version),
     /// The [`PythonTarget`] specifier is a set of version specifiers, as extracted from the
     /// `Requires-Python` field in a `pyproject.toml` or `METADATA` file.
     RequiresPython(RequiresPython),
