@@ -1,8 +1,10 @@
+pub use environments::SupportedEnvironments;
 pub use workspace::{
     check_nested_workspaces, DiscoveryOptions, ProjectWorkspace, VirtualProject, Workspace,
     WorkspaceError, WorkspaceMember,
 };
 
+mod environments;
 pub mod pyproject;
 pub mod pyproject_mut;
 mod workspace;
