@@ -16,7 +16,7 @@ use uv_cache::Cache;
 use uv_client::{BaseClientBuilder, Connectivity, FlatIndexClient, RegistryClientBuilder};
 use uv_configuration::{
     BuildOptions, Concurrency, ConfigSettings, ExtrasSpecification, IndexStrategy, NoBinary,
-    NoBuild, PreviewMode, Reinstall, SetupPyStrategy, SourceStrategy, Upgrade,
+    NoBuild, Reinstall, SourceStrategy, Upgrade,
 };
 use uv_configuration::{KeyringProviderType, TargetTriple};
 use uv_dispatch::BuildDispatch;
@@ -73,7 +73,6 @@ pub(crate) async fn pip_compile(
     index_locations: IndexLocations,
     index_strategy: IndexStrategy,
     keyring_provider: KeyringProviderType,
-    setup_py: SetupPyStrategy,
     config_settings: ConfigSettings,
     connectivity: Connectivity,
     no_build_isolation: bool,
@@ -92,7 +91,6 @@ pub(crate) async fn pip_compile(
     concurrency: Concurrency,
     native_tls: bool,
     quiet: bool,
-    preview: PreviewMode,
     cache: Cache,
     printer: Printer,
 ) -> Result<ExitStatus> {
@@ -251,7 +249,7 @@ pub(crate) async fn pip_compile(
             resolution_environment(python_version, python_platform, &interpreter)?;
         (
             Some(tags),
-            ResolverMarkers::SpecificEnvironment((*markers).clone()),
+            ResolverMarkers::specific_environment((*markers).clone()),
         )
     };
 
@@ -323,7 +321,6 @@ pub(crate) async fn pip_compile(
         &git,
         &in_flight,
         index_strategy,
-        setup_py,
         &config_settings,
         build_isolation,
         link_mode,
@@ -331,7 +328,6 @@ pub(crate) async fn pip_compile(
         exclude_newer,
         sources,
         concurrency,
-        preview,
     );
 
     let options = OptionsBuilder::new()
@@ -368,7 +364,6 @@ pub(crate) async fn pip_compile(
         options,
         Box::new(DefaultResolveLogger),
         printer,
-        preview,
     )
     .await
     {
