@@ -1,7 +1,8 @@
 use std::collections::hash_map::Entry;
-use std::path::PathBuf;
+use std::fmt::Write;
+use std::path::{Path, PathBuf};
 
-use anyhow::{Context, Result};
+use anyhow::{bail, Context, Result};
 use cache_key::RepositoryUrl;
 use owo_colors::OwoColorize;
 use pep508_rs::{ExtraName, Requirement, VersionOrUrl};
@@ -10,12 +11,10 @@ use tracing::debug;
 use uv_auth::{store_credentials_from_url, Credentials};
 use uv_cache::Cache;
 use uv_client::{BaseClientBuilder, Connectivity, FlatIndexClient, RegistryClientBuilder};
-use uv_configuration::{
-    Concurrency, ExtrasSpecification, PreviewMode, SetupPyStrategy, SourceStrategy,
-};
+use uv_configuration::{Concurrency, ExtrasSpecification, SourceStrategy};
 use uv_dispatch::BuildDispatch;
 use uv_distribution::DistributionDatabase;
-use uv_fs::CWD;
+use uv_fs::{Simplified, CWD};
 use uv_git::GIT_STORE;
 use uv_normalize::PackageName;
 use uv_python::{
@@ -60,15 +59,31 @@ pub(crate) async fn add(
     script: Option<PathBuf>,
     python_preference: PythonPreference,
     python_downloads: PythonDownloads,
-    preview: PreviewMode,
+
     connectivity: Connectivity,
     concurrency: Concurrency,
     native_tls: bool,
     cache: &Cache,
     printer: Printer,
 ) -> Result<ExitStatus> {
-    if preview.is_disabled() {
-        warn_user_once!("`uv add` is experimental and may change without warning");
+    for source in &requirements {
+        match source {
+            RequirementsSource::PyprojectToml(_) => {
+                bail!("Adding requirements from a `pyproject.toml` is not supported in `uv add`");
+            }
+            RequirementsSource::SetupPy(_) => {
+                bail!("Adding requirements from a `setup.py` is not supported in `uv add`");
+            }
+            RequirementsSource::SetupCfg(_) => {
+                bail!("Adding requirements from a `setup.cfg` is not supported in `uv add`");
+            }
+            RequirementsSource::RequirementsTxt(path) => {
+                if path == Path::new("-") {
+                    bail!("Reading requirements from stdin is not supported in `uv add`");
+                }
+            }
+            _ => {}
+        }
     }
 
     let reporter = PythonDownloadReporter::single(printer);
@@ -219,7 +234,6 @@ pub(crate) async fn add(
     let python_version = None;
     let python_platform = None;
     let hasher = HashStrategy::default();
-    let setup_py = SetupPyStrategy::default();
     let build_isolation = BuildIsolation::default();
 
     // Determine the environment for the resolution.
@@ -264,7 +278,6 @@ pub(crate) async fn add(
         &state.git,
         &state.in_flight,
         settings.index_strategy,
-        setup_py,
         &settings.config_setting,
         build_isolation,
         settings.link_mode,
@@ -272,7 +285,6 @@ pub(crate) async fn add(
         settings.exclude_newer,
         sources,
         concurrency,
-        preview,
     );
 
     // Resolve any unnamed requirements.
@@ -280,7 +292,7 @@ pub(crate) async fn add(
         requirements,
         &hasher,
         &state.index,
-        DistributionDatabase::new(&client, &build_dispatch, concurrency.downloads, preview),
+        DistributionDatabase::new(&client, &build_dispatch, concurrency.downloads),
     )
     .with_reporter(ResolverReporter::from(printer))
     .resolve()
@@ -405,9 +417,17 @@ pub(crate) async fn add(
         }
     };
 
-    // If `--script`, exit early. There's no reason to lock and sync.
-    let Target::Project(project, venv) = target else {
-        return Ok(ExitStatus::Success);
+    let (project, venv) = match target {
+        Target::Project(project, venv) => (project, venv),
+        // If `--script`, exit early. There's no reason to lock and sync.
+        Target::Script(script, _) => {
+            writeln!(
+                printer.stderr(),
+                "Updated `{}`",
+                script.path.user_display().cyan()
+            )?;
+            return Ok(ExitStatus::Success);
+        }
     };
 
     // If `--frozen`, exit early. There's no reason to lock and sync, and we don't need a `uv.lock`
@@ -432,7 +452,6 @@ pub(crate) async fn add(
         venv.interpreter(),
         settings.as_ref().into(),
         Box::new(DefaultResolveLogger),
-        preview,
         connectivity,
         concurrency,
         native_tls,
@@ -570,7 +589,6 @@ pub(crate) async fn add(
         settings.as_ref().into(),
         &state,
         Box::new(DefaultInstallLogger),
-        preview,
         connectivity,
         concurrency,
         native_tls,
