@@ -5,25 +5,15 @@ use itertools::Itertools;
 use owo_colors::OwoColorize;
 use tracing::debug;
 
-use uv_configuration::PreviewMode;
 use uv_fs::Simplified;
 use uv_normalize::PackageName;
 use uv_tool::{InstalledTools, Tool, ToolEntrypoint};
-use uv_warnings::warn_user_once;
 
 use crate::commands::ExitStatus;
 use crate::printer::Printer;
 
 /// Uninstall a tool.
-pub(crate) async fn uninstall(
-    name: Option<PackageName>,
-    preview: PreviewMode,
-    printer: Printer,
-) -> Result<ExitStatus> {
-    if preview.is_disabled() {
-        warn_user_once!("`uv tool uninstall` is experimental and may change without warning");
-    }
-
+pub(crate) async fn uninstall(name: Option<PackageName>, printer: Printer) -> Result<ExitStatus> {
     let installed_tools = InstalledTools::from_settings()?.init()?;
     let _lock = match installed_tools.acquire_lock() {
         Ok(lock) => lock,
@@ -37,6 +27,28 @@ pub(crate) async fn uninstall(
         Err(err) => return Err(err.into()),
     };
 
+    // Perform the uninstallation.
+    do_uninstall(&installed_tools, name, printer).await?;
+
+    // Clean up any empty directories.
+    if uv_fs::directories(installed_tools.root()).all(|path| uv_fs::is_temporary(&path)) {
+        fs_err::tokio::remove_dir_all(&installed_tools.root()).await?;
+        if let Some(top_level) = installed_tools.root().parent() {
+            if uv_fs::directories(top_level).all(|path| uv_fs::is_temporary(&path)) {
+                fs_err::tokio::remove_dir_all(top_level).await?;
+            }
+        }
+    }
+
+    Ok(ExitStatus::Success)
+}
+
+/// Perform the uninstallation.
+async fn do_uninstall(
+    installed_tools: &InstalledTools,
+    name: Option<PackageName>,
+    printer: Printer,
+) -> Result<()> {
     let mut dangling = false;
     let mut entrypoints = if let Some(name) = name {
         let Some(receipt) = installed_tools.get_tool_receipt(&name)? else {
@@ -47,7 +59,7 @@ pub(crate) async fn uninstall(
                         printer.stderr(),
                         "Removed dangling environment for `{name}`"
                     )?;
-                    return Ok(ExitStatus::Success);
+                    return Ok(());
                 }
                 Err(uv_tool::Error::Io(err)) if err.kind() == std::io::ErrorKind::NotFound => {
                     bail!("`{name}` is not installed");
@@ -58,7 +70,7 @@ pub(crate) async fn uninstall(
             }
         };
 
-        uninstall_tool(&name, &receipt, &installed_tools).await?
+        uninstall_tool(&name, &receipt, installed_tools).await?
     } else {
         let mut entrypoints = vec![];
         for (name, receipt) in installed_tools.tools()? {
@@ -82,7 +94,7 @@ pub(crate) async fn uninstall(
                 }
             };
 
-            entrypoints.extend(uninstall_tool(&name, &receipt, &installed_tools).await?);
+            entrypoints.extend(uninstall_tool(&name, &receipt, installed_tools).await?);
         }
         entrypoints
     };
@@ -93,7 +105,7 @@ pub(crate) async fn uninstall(
         if !dangling {
             writeln!(printer.stderr(), "Nothing to uninstall")?;
         }
-        return Ok(ExitStatus::Success);
+        return Ok(());
     }
 
     let s = if entrypoints.len() == 1 { "" } else { "s" };
@@ -107,7 +119,7 @@ pub(crate) async fn uninstall(
             .join(", ")
     )?;
 
-    Ok(ExitStatus::Success)
+    Ok(())
 }
 
 /// Uninstall a tool.
