@@ -208,13 +208,13 @@ fn root_package_splits_transitive_too() -> Result<()> {
     assert_snapshot!(fs_err::read_to_string(context.temp_dir.join("uv.lock"))?, @r###"
     version = 1
     requires-python = ">=3.11, <3.13"
-    environment-markers = [
+    resolution-markers = [
         "python_full_version < '3.12'",
         "python_full_version >= '3.12'",
     ]
 
     [options]
-    exclude-newer = "2024-03-25 00:00:00 UTC"
+    exclude-newer = "2024-03-25T00:00:00Z"
 
     [[package]]
     name = "a"
@@ -237,7 +237,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
     name = "anyio"
     version = "4.2.0"
     source = { registry = "https://pypi.org/simple" }
-    environment-markers = [
+    resolution-markers = [
         "python_full_version < '3.12'",
     ]
     dependencies = [
@@ -253,7 +253,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
     name = "anyio"
     version = "4.3.0"
     source = { registry = "https://pypi.org/simple" }
-    environment-markers = [
+    resolution-markers = [
         "python_full_version >= '3.12'",
     ]
     dependencies = [
@@ -315,7 +315,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
     name = "iniconfig"
     version = "1.1.1"
     source = { url = "https://files.pythonhosted.org/packages/9b/dd/b3c12c6d707058fa947864b67f0c4e0c39ef8610988d7baea9578f3c48f3/iniconfig-1.1.1-py2.py3-none-any.whl" }
-    environment-markers = [
+    resolution-markers = [
         "python_full_version < '3.12'",
     ]
     wheels = [
@@ -326,7 +326,7 @@ fn root_package_splits_transitive_too() -> Result<()> {
     name = "iniconfig"
     version = "2.0.0"
     source = { url = "https://files.pythonhosted.org/packages/ef/a6/62565a6e1cf69e10f5727360368e451d4b7f58beeac6173dc9db836a5b46/iniconfig-2.0.0-py3-none-any.whl" }
-    environment-markers = [
+    resolution-markers = [
         "python_full_version >= '3.12'",
     ]
     wheels = [
@@ -403,13 +403,13 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
     assert_snapshot!(fs_err::read_to_string(context.temp_dir.join("uv.lock"))?, @r###"
     version = 1
     requires-python = ">=3.11, <3.13"
-    environment-markers = [
+    resolution-markers = [
         "python_full_version < '3.12'",
         "python_full_version >= '3.12'",
     ]
 
     [options]
-    exclude-newer = "2024-03-25 00:00:00 UTC"
+    exclude-newer = "2024-03-25T00:00:00Z"
 
     [[package]]
     name = "a"
@@ -434,7 +434,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
     name = "anyio"
     version = "4.2.0"
     source = { registry = "https://pypi.org/simple" }
-    environment-markers = [
+    resolution-markers = [
         "python_full_version < '3.12'",
     ]
     dependencies = [
@@ -450,7 +450,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
     name = "anyio"
     version = "4.3.0"
     source = { registry = "https://pypi.org/simple" }
-    environment-markers = [
+    resolution-markers = [
         "python_full_version >= '3.12'",
     ]
     dependencies = [
@@ -497,7 +497,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
     name = "iniconfig"
     version = "1.1.1"
     source = { registry = "https://pypi.org/simple" }
-    environment-markers = [
+    resolution-markers = [
         "python_full_version < '3.12'",
     ]
     sdist = { url = "https://files.pythonhosted.org/packages/23/a2/97899f6bd0e873fed3a7e67ae8d3a08b21799430fb4da15cfedf10d6e2c2/iniconfig-1.1.1.tar.gz", hash = "sha256:bc3af051d7d14b2ee5ef9969666def0cd1a000e121eaea580d4a313df4b37f32", size = 8104 }
@@ -509,7 +509,7 @@ fn root_package_splits_other_dependencies_too() -> Result<()> {
     name = "iniconfig"
     version = "2.0.0"
     source = { registry = "https://pypi.org/simple" }
-    environment-markers = [
+    resolution-markers = [
         "python_full_version >= '3.12'",
     ]
     sdist = { url = "https://files.pythonhosted.org/packages/d7/4b/cbd8e699e64a6f16ca3a8220661b5f83792b3017d0f79807cb8708d33913/iniconfig-2.0.0.tar.gz", hash = "sha256:2d91e135bf72d31a410b17c16da610a82cb55f6b0477d1a902134b24a455b8b3", size = 4646 }
@@ -564,13 +564,13 @@ fn branching_between_registry_and_direct_url() -> Result<()> {
     assert_snapshot!(fs_err::read_to_string(context.temp_dir.join("uv.lock"))?, @r###"
     version = 1
     requires-python = ">=3.11, <3.13"
-    environment-markers = [
+    resolution-markers = [
         "python_full_version < '3.12'",
         "python_full_version >= '3.12'",
     ]
 
     [options]
-    exclude-newer = "2024-03-25 00:00:00 UTC"
+    exclude-newer = "2024-03-25T00:00:00Z"
 
     [[package]]
     name = "a"
@@ -591,7 +591,7 @@ fn branching_between_registry_and_direct_url() -> Result<()> {
     name = "iniconfig"
     version = "1.1.1"
     source = { registry = "https://pypi.org/simple" }
-    environment-markers = [
+    resolution-markers = [
         "python_full_version < '3.12'",
     ]
     sdist = { url = "https://files.pythonhosted.org/packages/23/a2/97899f6bd0e873fed3a7e67ae8d3a08b21799430fb4da15cfedf10d6e2c2/iniconfig-1.1.1.tar.gz", hash = "sha256:bc3af051d7d14b2ee5ef9969666def0cd1a000e121eaea580d4a313df4b37f32", size = 8104 }
@@ -603,7 +603,7 @@ fn branching_between_registry_and_direct_url() -> Result<()> {
     name = "iniconfig"
     version = "2.0.0"
     source = { url = "https://files.pythonhosted.org/packages/ef/a6/62565a6e1cf69e10f5727360368e451d4b7f58beeac6173dc9db836a5b46/iniconfig-2.0.0-py3-none-any.whl" }
-    environment-markers = [
+    resolution-markers = [
         "python_full_version >= '3.12'",
     ]
     wheels = [
@@ -649,13 +649,13 @@ fn branching_urls_of_different_sources_disjoint() -> Result<()> {
     assert_snapshot!(fs_err::read_to_string(context.temp_dir.join("uv.lock"))?, @r###"
     version = 1
     requires-python = ">=3.11, <3.13"
-    environment-markers = [
+    resolution-markers = [
         "python_full_version < '3.12'",
         "python_full_version >= '3.12'",
     ]
 
     [options]
-    exclude-newer = "2024-03-25 00:00:00 UTC"
+    exclude-newer = "2024-03-25T00:00:00Z"
 
     [[package]]
     name = "a"
@@ -676,7 +676,7 @@ fn branching_urls_of_different_sources_disjoint() -> Result<()> {
     name = "iniconfig"
     version = "1.1.1"
     source = { url = "https://files.pythonhosted.org/packages/9b/dd/b3c12c6d707058fa947864b67f0c4e0c39ef8610988d7baea9578f3c48f3/iniconfig-1.1.1-py2.py3-none-any.whl" }
-    environment-markers = [
+    resolution-markers = [
         "python_full_version < '3.12'",
     ]
     wheels = [
@@ -687,7 +687,7 @@ fn branching_urls_of_different_sources_disjoint() -> Result<()> {
     name = "iniconfig"
     version = "2.0.0"
     source = { git = "https://github.com/pytest-dev/iniconfig?rev=93f5930e668c0d1ddf4597e38dd0dea4e2665e7a#93f5930e668c0d1ddf4597e38dd0dea4e2665e7a" }
-    environment-markers = [
+    resolution-markers = [
         "python_full_version >= '3.12'",
     ]
     "###);
@@ -778,7 +778,7 @@ fn dont_pre_visit_url_packages() -> Result<()> {
     requires-python = ">=3.11, <3.13"
 
     [options]
-    exclude-newer = "2024-03-25 00:00:00 UTC"
+    exclude-newer = "2024-03-25T00:00:00Z"
 
     [[package]]
     name = "a"
