@@ -16,20 +16,21 @@ fn help() {
     Usage: uv [OPTIONS] <COMMAND>
 
     Commands:
-      run      Run a command or script (experimental)
-      init     Create a new project (experimental)
-      add      Add dependencies to the project (experimental)
-      remove   Remove dependencies from the project (experimental)
-      sync     Update the project's environment (experimental)
-      lock     Update the project's lockfile (experimental)
-      tree     Display the project's dependency tree (experimental)
-      tool     Run and install commands provided by Python packages (experimental)
-      python   Manage Python versions and installations (experimental)
-      pip      Manage Python packages with a pip-compatible interface
-      venv     Create a virtual environment
-      cache    Manage uv's cache
-      version  Display uv's version
-      help     Display documentation for a command
+      run                        Run a command or script
+      init                       Create a new project
+      add                        Add dependencies to the project
+      remove                     Remove dependencies from the project
+      sync                       Update the project's environment
+      lock                       Update the project's lockfile
+      tree                       Display the project's dependency tree
+      tool                       Run and install commands provided by Python packages
+      python                     Manage Python versions and installations
+      pip                        Manage Python packages with a pip-compatible interface
+      venv                       Create a virtual environment
+      cache                      Manage uv's cache
+      version                    Display uv's version
+      generate-shell-completion  Generate shell completion
+      help                       Display documentation for a command
 
     Cache options:
       -n, --no-cache               Avoid reading from or writing to the cache, instead using a temporary
@@ -78,15 +79,15 @@ fn help_flag() {
     Usage: uv [OPTIONS] <COMMAND>
 
     Commands:
-      run      Run a command or script (experimental)
-      init     Create a new project (experimental)
-      add      Add dependencies to the project (experimental)
-      remove   Remove dependencies from the project (experimental)
-      sync     Update the project's environment (experimental)
-      lock     Update the project's lockfile (experimental)
-      tree     Display the project's dependency tree (experimental)
-      tool     Run and install commands provided by Python packages (experimental)
-      python   Manage Python versions and installations (experimental)
+      run      Run a command or script
+      init     Create a new project
+      add      Add dependencies to the project
+      remove   Remove dependencies from the project
+      sync     Update the project's environment
+      lock     Update the project's lockfile
+      tree     Display the project's dependency tree
+      tool     Run and install commands provided by Python packages
+      python   Manage Python versions and installations
       pip      Manage Python packages with a pip-compatible interface
       venv     Create a virtual environment
       cache    Manage uv's cache
@@ -139,15 +140,15 @@ fn help_short_flag() {
     Usage: uv [OPTIONS] <COMMAND>
 
     Commands:
-      run      Run a command or script (experimental)
-      init     Create a new project (experimental)
-      add      Add dependencies to the project (experimental)
-      remove   Remove dependencies from the project (experimental)
-      sync     Update the project's environment (experimental)
-      lock     Update the project's lockfile (experimental)
-      tree     Display the project's dependency tree (experimental)
-      tool     Run and install commands provided by Python packages (experimental)
-      python   Manage Python versions and installations (experimental)
+      run      Run a command or script
+      init     Create a new project
+      add      Add dependencies to the project
+      remove   Remove dependencies from the project
+      sync     Update the project's environment
+      lock     Update the project's lockfile
+      tree     Display the project's dependency tree
+      tool     Run and install commands provided by Python packages
+      python   Manage Python versions and installations
       pip      Manage Python packages with a pip-compatible interface
       venv     Create a virtual environment
       cache    Manage uv's cache
@@ -196,7 +197,7 @@ fn help_subcommand() {
     success: true
     exit_code: 0
     ----- stdout -----
-    Manage Python versions and installations (experimental)
+    Manage Python versions and installations
 
     Generally, uv first searches for Python in a virtual environment, either
     active or in a `.venv` directory  in the current working directory or
@@ -207,8 +208,7 @@ fn help_subcommand() {
     On Windows, the `py` launcher is also invoked to find Python
     executables.
 
-    When preview is enabled, i.e., via `--preview` or by using a preview
-    command, uv will download Python if a version cannot be found. This
+    By default, uv will download Python if a version cannot be found. This
     behavior can be disabled with the `--python-downloads` option.
 
     The `--python` option allows requesting a different interpreter.
@@ -512,7 +512,7 @@ fn help_flag_subcommand() {
     success: true
     exit_code: 0
     ----- stdout -----
-    Manage Python versions and installations (experimental)
+    Manage Python versions and installations
 
     Usage: uv python [OPTIONS] <COMMAND>
 
@@ -632,6 +632,7 @@ fn help_unknown_subcommand() {
         venv
         cache
         version
+        generate-shell-completion
     "###);
 
     uv_snapshot!(context.filters(), context.help().arg("foo").arg("bar"), @r###"
@@ -654,6 +655,7 @@ fn help_unknown_subcommand() {
         venv
         cache
         version
+        generate-shell-completion
     "###);
 }
 
@@ -690,20 +692,21 @@ fn help_with_global_option() {
     Usage: uv [OPTIONS] <COMMAND>
 
     Commands:
-      run      Run a command or script (experimental)
-      init     Create a new project (experimental)
-      add      Add dependencies to the project (experimental)
-      remove   Remove dependencies from the project (experimental)
-      sync     Update the project's environment (experimental)
-      lock     Update the project's lockfile (experimental)
-      tree     Display the project's dependency tree (experimental)
-      tool     Run and install commands provided by Python packages (experimental)
-      python   Manage Python versions and installations (experimental)
-      pip      Manage Python packages with a pip-compatible interface
-      venv     Create a virtual environment
-      cache    Manage uv's cache
-      version  Display uv's version
-      help     Display documentation for a command
+      run                        Run a command or script
+      init                       Create a new project
+      add                        Add dependencies to the project
+      remove                     Remove dependencies from the project
+      sync                       Update the project's environment
+      lock                       Update the project's lockfile
+      tree                       Display the project's dependency tree
+      tool                       Run and install commands provided by Python packages
+      python                     Manage Python versions and installations
+      pip                        Manage Python packages with a pip-compatible interface
+      venv                       Create a virtual environment
+      cache                      Manage uv's cache
+      version                    Display uv's version
+      generate-shell-completion  Generate shell completion
+      help                       Display documentation for a command
 
     Cache options:
       -n, --no-cache               Avoid reading from or writing to the cache, instead using a temporary
@@ -788,20 +791,21 @@ fn help_with_no_pager() {
     Usage: uv [OPTIONS] <COMMAND>
 
     Commands:
-      run      Run a command or script (experimental)
-      init     Create a new project (experimental)
-      add      Add dependencies to the project (experimental)
-      remove   Remove dependencies from the project (experimental)
-      sync     Update the project's environment (experimental)
-      lock     Update the project's lockfile (experimental)
-      tree     Display the project's dependency tree (experimental)
-      tool     Run and install commands provided by Python packages (experimental)
-      python   Manage Python versions and installations (experimental)
-      pip      Manage Python packages with a pip-compatible interface
-      venv     Create a virtual environment
-      cache    Manage uv's cache
-      version  Display uv's version
-      help     Display documentation for a command
+      run                        Run a command or script
+      init                       Create a new project
+      add                        Add dependencies to the project
+      remove                     Remove dependencies from the project
+      sync                       Update the project's environment
+      lock                       Update the project's lockfile
+      tree                       Display the project's dependency tree
+      tool                       Run and install commands provided by Python packages
+      python                     Manage Python versions and installations
+      pip                        Manage Python packages with a pip-compatible interface
+      venv                       Create a virtual environment
+      cache                      Manage uv's cache
+      version                    Display uv's version
+      generate-shell-completion  Generate shell completion
+      help                       Display documentation for a command
 
     Cache options:
       -n, --no-cache               Avoid reading from or writing to the cache, instead using a temporary
